==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_results/mp1287_001/MP1287_Store2StoreTransfer_001_Result.java <==

package net.datastream.schemas.mp_results.mp1287_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="ResultData">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <element name="ISSUETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
 *                   <element name="RECEIVETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP1287_Store2StoreTransfer_001_Result")
public class MP1287_Store2StoreTransfer_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP1287_Store2StoreTransfer_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP1287_Store2StoreTransfer_001_Result.ResultData }
     *     
     */
    public MP1287_Store2StoreTransfer_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP1287_Store2StoreTransfer_001_Result.ResultData }
     *     
     */
    public void setResultData(MP1287_Store2StoreTransfer_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <element name="ISSUETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
     *         <element name="RECEIVETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "issuetransactionid",
        "receivetransactionid"
    })
    public static class ResultData {

        @XmlElement(name = "ISSUETRANSACTIONID", required = true)
        protected TRANSACTIONID_Type issuetransactionid;
        @XmlElement(name = "RECEIVETRANSACTIONID", required = true)
        protected TRANSACTIONID_Type receivetransactionid;

        /**
         * Gets the value of the issuetransactionid property.
         * 
         * @return
         *     possible object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public TRANSACTIONID_Type getISSUETRANSACTIONID() {
            return issuetransactionid;
        }

        /**
         * Sets the value of the issuetransactionid property.
         * 
         * @param value
         *     allowed object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public void setISSUETRANSACTIONID(TRANSACTIONID_Type value) {
            this.issuetransactionid = value;
        }

        /**
         * Gets the value of the receivetransactionid property.
         * 
         * @return
         *     possible object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public TRANSACTIONID_Type getRECEIVETRANSACTIONID() {
            return receivetransactionid;
        }

        /**
         * Sets the value of the receivetransactionid property.
         * 
         * @param value
         *     allowed object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public void setRECEIVETRANSACTIONID(TRANSACTIONID_Type value) {
            this.receivetransactionid = value;
        }

    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_results/mp1287_001/MP1287_Store2StoreTransfer_001_Result.java <==

package net.datastream.schemas.mp_results.mp1287_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="ISSUETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
 *                   &lt;element name="RECEIVETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP1287_Store2StoreTransfer_001_Result")
public class MP1287_Store2StoreTransfer_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP1287_Store2StoreTransfer_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP1287_Store2StoreTransfer_001_Result.ResultData }
     *     
     */
    public MP1287_Store2StoreTransfer_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP1287_Store2StoreTransfer_001_Result.ResultData }
     *     
     */
    public void setResultData(MP1287_Store2StoreTransfer_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="ISSUETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
     *         &lt;element name="RECEIVETRANSACTIONID" type="{http://schemas.datastream.net/MP_fields}TRANSACTIONID_Type"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "issuetransactionid",
        "receivetransactionid"
    })
    public static class ResultData {

        @XmlElement(name = "ISSUETRANSACTIONID", required = true)
        protected TRANSACTIONID_Type issuetransactionid;
        @XmlElement(name = "RECEIVETRANSACTIONID", required = true)
        protected TRANSACTIONID_Type receivetransactionid;

        /**
         * Gets the value of the issuetransactionid property.
         * 
         * @return
         *     possible object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public TRANSACTIONID_Type getISSUETRANSACTIONID() {
            return issuetransactionid;
        }

        /**
         * Sets the value of the issuetransactionid property.
         * 
         * @param value
         *     allowed object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public void setISSUETRANSACTIONID(TRANSACTIONID_Type value) {
            this.issuetransactionid = value;
        }

        /**
         * Gets the value of the receivetransactionid property.
         * 
         * @return
         *     possible object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public TRANSACTIONID_Type getRECEIVETRANSACTIONID() {
            return receivetransactionid;
        }

        /**
         * Sets the value of the receivetransactionid property.
         * 
         * @param value
         *     allowed object is
         *     {@link TRANSACTIONID_Type }
         *     
         */
        public void setRECEIVETRANSACTIONID(TRANSACTIONID_Type value) {
            this.receivetransactionid = value;
        }

    }

}
